import{d as s,a5 as m,z as n,X as e,c as l,g as c,f as u,b as f}from"./index-d8f72d9c.js";import{I as h}from"./ItemsListing-27042dbc.js";import"./VCheckbox-78132c43.js";import"./eventbus-55fa23b1.js";import"./VListItem-99f39ae4.js";import"./VCheckboxBtn-c3c8d14c.js";import"./VList-288ded64.js";import"./VCardText-361d19f4.js";import"./VCard-120d3152.js";import"./VMenu-c477cd50.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-d2f27c63.js";import"./Button-257b972a.js";import"./VSpacer-b6fa50b4.js";/* empty css              */import"./PanelviewItemCompact-f59c8796.js";import"./VAlert-74e6b24d.js";import"./Container-b694a4b0.js";import"./Toolbar-171f4c01.js";import"./VToolbar-46cf4633.js";import"./VTextField-1865982e.js";import"./VInfiniteScroll-8a11bc5d.js";import"./layout-3d7c6c32.js";import"./VVirtualScroll-b2e23632.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{J as default};
